@@ -6,6 +6,8 @@ use feature qw /postderef signatures/;
 package Vote::Count::Matrix;
 use Moose;
 
+use Vote::Count::RankCount;
+
 no warnings 'experimental';
 use List::Util qw( min max sum );
 use TextTableTiny  qw/generate_markdown_table/;
@@ -16,13 +18,13 @@ use Data::Dumper;
 
 use YAML::XS;
 
-our $VERSION='0.011';
+our $VERSION='0.012';
 
 =head1 NAME
 
 Vote::Count::Matrix
 
-=head1 VERSION 0.011
+=head1 VERSION 0.012
 
 =cut
 
@@ -196,6 +198,33 @@ sub CondorcetWinner( $self ) {
   return $winner;
 }
 
+sub GreatestLoss ( $self, $A ) {
+  my $bigloss = 0;
+GREATESTLOSSLOOP:
+    for my $B ( keys $self->Active()->%* ) {
+      next GREATESTLOSSLOOP if $B eq $A;
+      my %result = $self->{'Matrix'}{$A}{$B}->%*;
+# warn "$A : $B loser $result{'loser'} : margin $result{'margin'} $A: $result{$A} $B: $result{$B}";
+      if ( $result{'loser'} eq $A ) {
+        $bigloss = $result{'margin'} if $result{'margin'} > $bigloss;
+      }
+    }
+  return $bigloss;
+}
+
+sub RankGreatestLoss ( $self ){
+  my %loss = ();
+  for my $A ( keys $self->Active()->%* ) {
+    $loss{$A} = $self->GreatestLoss( $A);
+  }
+  return Vote::Count::RankCount->Rank( \%loss );
+}
+
+# reset active to choices
+sub ResetActive ( $self ) {
+  $self->{'Active'} = $self->BallotSet->{'choices'};
+}
+
 sub _getsmithguessforchoice ( $h, $matrix ) {
   my @winners = ($h);
   for my $P ( keys $matrix->{$h}->%* ) {
@@ -251,6 +280,15 @@ SMITHLOOP: while (1) {
   return $proposal;
 }
 
+# ScoreMatrix as a table.
+sub ScoreTable ( $self ) {
+  my $scores = $self->ScoreMatrix();
+  my @header = ( 'Choice', 'Score' );
+  my @rows = ( \@header );
+  for my $c ( sort keys $scores->%* ) {push @rows, [ $c, $scores->{$c} ] }
+  return generate_markdown_table( rows => \@rows );
+}
+
 # options may later be used to add rankcount objects
 # from Borda, approval, and topcount.
 sub MatrixTable ( $self, $options = {} ) {
@@ -285,6 +323,28 @@ sub MatrixTable ( $self, $options = {} ) {
   return generate_markdown_table( rows => \@rows );
 }
 
+sub PairingVotesTable ( $self ) {
+  my @rows = ( [ qw/Choice Choice Votes Opponent Votes/]);
+  my @choices = sort ( keys $self->Active()->%* );
+  for my $Choice ( @choices) {
+    push @rows, [ $Choice ];
+    for my $Opponent ( @choices) {
+      my $Cstr = $Choice; my $Ostr = $Opponent;
+      next if $Opponent eq $Choice;
+      my $CVote = $self->{'Matrix'}{$Choice}{$Opponent}{$Choice};
+      my $OVote = $self->{'Matrix'}{$Choice}{$Opponent}{$Opponent};
+      if ($self->{'Matrix'}{$Choice}{$Opponent}{'winner'} eq $Choice ) {
+        $Cstr = "*$Cstr*";
+      }
+      if ($self->{'Matrix'}{$Choice}{$Opponent}{'winner'} eq $Opponent ) {
+        $Ostr = "*$Ostr*";
+      }
+      push @rows, [ ' ', $Cstr, $CVote, $Ostr, $OVote ];
+    }
+  }
+  return generate_markdown_table( rows => \@rows );
+}
+
 1;
 
 #buildpod
@@ -298,6 +358,7 @@ Condorcet Pairwise Methods require a Win-Loss Matrix. This object takes an RCV B
 
 =head1 SYNOPSIS
 
+
  my $Matrix =
    Vote::Count::Matrix->new(
      'BallotSet' => $myVoteCount->BallotSet() );
@@ -335,11 +396,17 @@ A hash reference with active choices as the keys. The default value is all of th
 Returns a MarkDown formatted table with the wins losses and ties for each Active Choice as text.
 
 
+=head2 PairingVotesTable
+
+Returns a MarkDown formatted table with the votes for all of the pairings.
+
+
 =head2 GetPairResult ( $A, $B )
 
 Returns the results of the pairing of two choices as a hashref.
 
- Example where $A and $B are "STRAWBERRY" and "FUDGESWIRL":
+
+   Example where $A and $B are "STRAWBERRY" and "FUDGESWIRL":
    {
     'FUDGESWIRL' =>  6,
     'loser'      =>  "STRAWBERRY",
@@ -361,6 +428,11 @@ Returns the winner of the pairing of two choices. If there is no Winner it retur
 Returns a HashRef of the choices and their Matrix Scores. The scoring is 1 for each win, 0 for losses and ties. In the event a choice has ties but no wins their score will be .001. Where N is the number of choices, a Condorcet Winner will have a score of N-1, a Condorcet Loser will have a score of 0. Since a choice with at least one tie but no wins is not defeated by all other choices they are not a Condorcet Loser, and thus those cases are scored with a near to zero value instead of 0. Methods that wish to treat no wins but tie case as a Condorcet Loser may test for a score less than 1.
 
 
+=head2 ScoreTable
+
+Returns the ScoreMatrix as a markdown compatible table.
+
+
 =head2 LeastWins
 
 Returns an array of the choice or choices with the fewest wins.
@@ -370,7 +442,8 @@ Returns an array of the choice or choices with the fewest wins.
 
 Eliminates all Condorcet Losers from the Matrix Object's Active list. Returns a hashref:
 
- {
+
+   {
      verbose => 'verbose message',
      terse   => 'terse message',
      eliminated => [ eliminated choices ],
@@ -390,6 +463,44 @@ Finds the innermost Smith Set (Dominant Set). [ assistance in finding proof of t
 
 Returns a hashref with the keys as the choices of the Smith Set.
 
+
+=head2 ResetActive
+
+Reset Active list to the choices lift of the BallotSet.
+
+
+=head2 GreatestLoss
+
+Returns the greatest loss for a choice C<<< $MyMatrix->GreatestLoss( $A ) >>>.
+
+
+=head2 RankGreatestLoss
+
+Returns a RankTable object of the Greatest Loss for each choice.
+
 =cut
 
-#buildpod
\ No newline at end of file
+#buildpod
+
+
+#FOOTER
+
+=pod
+
+BUG TRACKER
+
+L<https://github.com/brainbuz/Vote-Count/issues>
+
+AUTHOR
+
+John Karr (BRAINBUZ) brainbuz@cpan.org
+
+CONTRIBUTORS
+
+Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+
+LICENSE
+
+This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
+
+=cut
\ No newline at end of file
